@@ -70,10 +70,10 @@ extern "C" {
 #define M_PI    3.14159265358979323846
 #endif
 
-class Registry
+class AudioRegistry
 {
 public:
-	Registry();
+	AudioRegistry();
 
 	const char *codecdir;
 };
@@ -83,17 +83,15 @@ extern LONG buffer_framing = 120;	// millisec
 extern LONG buffer_count = 8;
 #endif
 
-static class Registry registry;
+static class AudioRegistry registry;
 
 #if	defined(CAPE_REGISTRY_PREFIX)
 #define	REGISTRY_AUDIO_SETTINGS CAPE_REGISTRY_PREFIX "\\Audio Settings"
-#elif defined(_MSC_VER) && _MSC_VER >= 1300
-#define	REGISTRY_AUDIO_SETTINGS "SOFTWARE\\CAPE Framework .NET\\Audio Settings"
 #else
 #define	REGISTRY_AUDIO_SETTINGS	"SOFTWARE\\CAPE Framework\\Audio Settings"
 #endif
 
-Registry::Registry()
+AudioRegistry::AudioRegistry()
 {
 #ifdef	W32
 	static TCHAR regpath[256];
@@ -307,7 +305,7 @@ Audio::Linear Audio::getDualTone(Linear buffer, timeout_t duration, unsigned f1,
 {
         double df1 = (f1 * M_PI * 2) / (long)rate;
 	double df2 = (f2 * M_PI * 2) / (long)rate;
-        double p1, p2 = 0;
+        double p1 = 0, p2 = 0;
 	size_t count;
         size_t samples = count = (duration * (long)rate) / 1000;
         Linear data;
@@ -406,7 +404,7 @@ Audio::Level Audio::getImpulse(Info &info, void *buffer, unsigned samples)
 	unsigned long sum = 0;
 	unsigned long count;
 	Sample *sp, mb;
-	bin16_t *up, ub;
+	snd16_t *up, ub;
 	unsigned char *sv = (unsigned char *)&mb, *s1, *s2;
 	unsigned char *uv = (unsigned char *)&ub;
 
@@ -427,7 +425,7 @@ Audio::Level Audio::getImpulse(Info &info, void *buffer, unsigned samples)
 		if(info.format == snd && (info.order == __BYTE_ORDER || !info.order))
 		{
 			count *= 2;
-			up = (bin16_t *)buffer;
+			up = (snd16_t *)buffer;
 			while(samples--)
 				sum += *(up++);
 			return (Level)(sum / count);
@@ -533,7 +531,7 @@ Audio::Level Audio::getPeak(Info &info, void *buffer, unsigned samples)
 	Level max = 0, value;
 	unsigned long count;
 	Sample *sp, mb;
-	bin16_t *up, ub;
+	snd16_t *up, ub;
 	unsigned char *sv = (unsigned char *)&mb, *s1, *s2;
 	unsigned char *uv = (unsigned char *)&ub;
 
@@ -554,7 +552,7 @@ Audio::Level Audio::getPeak(Info &info, void *buffer, unsigned samples)
 		if(info.format == snd && (info.order == __BYTE_ORDER || !info.order))
 		{
 			count *= 2;
-			up = (bin16_t *)buffer;
+			up = (snd16_t *)buffer;
 			while(samples--)
 			{
 				value = (Level)(*(up++) / 2);
